# -*- coding: utf-8 -*-
from allink_core.core.views import AllinkBasePluginLoadMoreView, AllinkBaseDetailView
from allink_core.core.loading import get_model


Testimonials = get_model('testimonials', 'Testimonials')
TestimonialsAppContentPlugin = get_model('testimonials', 'TestimonialsAppContentPlugin')


class TestimonialsPluginLoadMore(AllinkBasePluginLoadMoreView):
    model = Testimonials
    plugin_model = TestimonialsAppContentPlugin


class TestimonialsDetail(AllinkBaseDetailView):
    model = Testimonials



# # -*- coding: utf-8 -*-
from django.urls import path
from allink_core.core.loading import get_class

ContactRequestView = get_class('contact.views', 'ContactRequestView')


urlpatterns = [
    path('request/<int:plugin_id>/', ContactRequestView.as_view(), name='request'),
]



# # -*- coding: utf-8 -*-
from django.urls import path

from allink_core.core.loading import get_class

TestimonialsPluginLoadMore = get_class('testimonials.views', 'TestimonialsPluginLoadMore')
TestimonialsDetail = get_class('testimonials.views', 'TestimonialsDetail')


urlpatterns = [
    path('<int:page>/', TestimonialsPluginLoadMore.as_view(), name='more'),
    path('<slug:slug>/', TestimonialsDetail.as_view(), name='detail'),
]



# -*- coding: utf-8 -*-
from parler.managers import TranslatableManager


class AllinkTermsManager(TranslatableManager):
    def get_published(self):
        from allink_core.core_apps.allink_terms.models import AllinkTerms
        return super(AllinkTermsManager, self).get(status=AllinkTerms.STATUS_PUBLISHED)



from django.conf import settings
from django.contrib.sitemaps import Sitemap
from cms.sitemaps import CMSSitemap
from cms.models.titlemodels import Title


class CMSHrefLangSitemap(CMSSitemap):
    """
    Base Sitemap class used for djangocms Page objects to provide a proper hreflang tag for each language

    further information: https://support.google.com/webmasters/answer/189077?hl=de

    """
    def _urls(self, page, protocol, domain):
        urls = super()._urls(page, protocol, domain)
        for url in urls:
            url['hreflang'] = []
            for lang in settings.LANGUAGES:
                title = url.get('item').page.get_title_obj(language=lang[0], fallback=False)
                if isinstance(title, Title):
                    url['hreflang'].append({
                        'lang': lang[0],
                        'href': "%s://%s/%s/%s/" % (protocol, domain, lang[0], title.slug)
                    })

        return urls


class HrefLangSitemap(Sitemap):
    """
    Base Sitemap class used in allink apps to provide a proper hreflang tag for each language

    further information: https://support.google.com/webmasters/answer/189077?hl=de

    """

    def _urls(self, page, protocol, domain):
        urls = super()._urls(page, protocol, domain)
        for url in urls:
            url['hreflang'] = []
            item = url.get('item')
            for lang in list(item.get_available_languages()):
                current_item = item.get_translation(lang)
                slug = current_item.slug
                url['hreflang'].append({
                    'lang': lang,
                    'href': "%s://%s/%s/%s/" % (protocol, domain, lang, slug)
                })

        return urls



# -*- coding: utf-8 -*-
from django import forms

from allink_core.core.forms.forms import AllinkBaseModelForm
from allink_core.core.loading import get_model

EventsRegistration = get_model('events', 'EventsRegistration')


class EventsRegistrationForm(AllinkBaseModelForm):

    class Meta:
        model = EventsRegistration
        widgets = {
            'event': forms.HiddenInput(),

        }
        fields = ('event', 'salutation', 'first_name', 'last_name', 'company_name', 'email', 'phone', 'message')

# for reference
# class EventsRegistrationTermsForm(AllinkBaseModelForm):
#
#     terms_accepted = forms.BooleanField(label='Terms of Service', required=True)
#
#     class Meta:
#         model = EventsRegistration
#         widgets = {
#             'event': forms.HiddenInput(),
#             'terms': forms.HiddenInput(),
#             'terms_accepted': forms.CheckboxInput()
#
#         }
#         fields = ('event', 'salutation', 'first_name', 'last_name', 'company_name', 'email', 'phone',
#         'message', 'terms', 'terms_accepted')
#
#     def __init__(self, *args, **kwargs):
#         super(EventsRegistrationTermsForm, self).__init__(*args, **kwargs)
#         try:
#             self.fields['terms_accepted'].label = mark_safe(_('I have read and accept the <a href="%s"
#             target="_blank">terms and conditions.</a>')) % (AllinkTerms.objects.get_published().terms_
#             cms_page.get_absolute_url())
#             self.fields['terms'].initial = AllinkTerms.objects.get_published()
#         except:
#             raise AttributeError(_('Please configure Terms. And create the corresponding cms Page.'))



# -*- coding: utf-8 -*-
from django import forms
from django.utils.translation import get_language, ugettext_lazy as _

from allink_core.core_apps.allink_mailchimp.config import MailChimpConfig
from allink_core.core_apps.allink_mailchimp.helpers import list_members_put, get_status_if_new
from allink_core.core.models.choices import SALUTATION_CHOICES, MR

config = MailChimpConfig()


class SignupForm(forms.Form):
    salutation = forms.IntegerField(
        label=_('Salutation'),
        widget=forms.RadioSelect(choices=SALUTATION_CHOICES),
        initial=MR
    )
    first_name = forms.CharField(
        label=_('First Name')
    )
    last_name = forms.CharField(
        label=_('Last Name')
    )
    email = forms.EmailField(
        label=_('Email')
    )
    language = forms.CharField(
        max_length=3, required=False
    )
    # gdpr permission options
    permission_direct_mail = forms.BooleanField(
        label=_('Email'),
        required=False
    )
    permission_personalised_online_advertising = forms.BooleanField(
        label=_('Personalised online advertising'),
        required=False
    )

    def save(self):
        salutation = 'Herr' if self.cleaned_data['salutation'] == 1 else 'Frau'
        email = self.cleaned_data['email']
        first_name = self.cleaned_data['first_name']
        last_name = self.cleaned_data['last_name']
        language = self.cleaned_data['language'] if 'language' in self.cleaned_data else get_language()
        permission_direct_mail = self.cleaned_data['permission_direct_mail']
        permission_personalised_online_advertising = self.cleaned_data['permission_personalised_online_advertising']

        data = {
            'email_address': email,
            'status': 'subscribed',
            'status_if_new': get_status_if_new(),
            'language': language,
            'merge_fields': {
                'GENDER': salutation,
                'FNAME': first_name,
                'LNAME': last_name,
                'GDPR_EMAIL': 'Yes' if permission_direct_mail else 'No',
                'GDPR_ADS': 'Yes' if permission_personalised_online_advertising else 'No',
            }
        }

        if config.merge_vars:
            data = data.update(config.merge_vars)

        list_members_put(data)



# -*- coding: utf-8 -*-
import datetime
from django.db import models

from cms.models.pluginmodel import CMSPlugin
from cms.models.fields import PageField
from parler.models import TranslatableModel, TranslatedFields
from djangocms_text_ckeditor.fields import HTMLField

from allink_core.core.models import AllinkTimeFramedModel
from allink_core.core_apps.allink_terms.managers import AllinkTermsManager


class AllinkTerms(AllinkTimeFramedModel, TranslatableModel):

    STATUS_DRAFT = 10
    STATUS_PUBLISHED = 20
    STATUS_ARCHIVED = 30

    STATUS_CHOICES = (
        (STATUS_DRAFT, 'Draft'),
        (STATUS_PUBLISHED, 'Published'),
        (STATUS_ARCHIVED, 'Archived'),
    )

    translations = TranslatedFields(
        text=HTMLField(
            'Terms Text'
        ),
    )

    terms_cms_page = PageField(
        verbose_name='Terms cms Page',
        null=True,
        on_delete=models.PROTECT,
        help_text='CMS Page which shows Terms and Conditions',
    )

    status = models.IntegerField('Status', choices=STATUS_CHOICES, default=STATUS_DRAFT)

    objects = AllinkTermsManager()

    class Meta:
        verbose_name = 'Terms of Service'
        verbose_name_plural = 'Terms of Service'
        app_label = 'allink_terms'

    def __str__(self):
        return 'Terms - %s' % self.get_status_display()

    def text_rendered(self):
        return self.text

    text_rendered.allow_tags = True

    @property
    def is_publishable(self):
        return self.status == AllinkTerms.STATUS_DRAFT

    def publish(self):
        self.save()
        now = datetime.datetime.now()

        try:
            curr_pub = AllinkTerms.objects.get_published()
            curr_pub.status = AllinkTerms.STATUS_ARCHIVED
            curr_pub.end = now
            curr_pub.save()
        except AllinkTerms.DoesNotExist:
            pass  # pass on first publication

        self.status = AllinkTerms.STATUS_PUBLISHED
        self.start = now
        self.save()

    def delete(self, *args, **kwargs):
        if self.status != AllinkTerms.STATUS_DRAFT:
            return  # can't delete models that already have been published
        return super(AllinkTerms, self).delete(*args, **kwargs)


class AllinkTermsPlugin(CMSPlugin):

    class Meta:
        app_label = 'allink_terms'

    def __str__(self):
        return str(self.pk)



# -*- coding: utf-8 -*-
from django.urls import reverse

from cms.toolbar_pool import toolbar_pool
from cms.toolbar_base import CMSToolbar

from allink_core.core_apps.allink_terms.models import AllinkTerms
from allink_core.core.loading import get_model

Config = get_model('config', 'Config')


class AllinkTermsToolbar(CMSToolbar):
    model = AllinkTerms

    def populate(self):
        menu = self.toolbar.get_or_create_menu(
            '{}-menu'.format(self.model._meta.model_name),
            '{}'.format(self.model._meta.verbose_name_plural)
        )
        url = reverse('admin:{}_{}_changelist'.format(self.model._meta.app_label, self.model._meta.model_name))
        menu.add_sideframe_item(self.model._meta.verbose_name_plural, url=url)


toolbar_pool.register(AllinkTermsToolbar)



# -*- coding: utf-8 -*-
from django import forms
from django.utils.translation import get_language, ugettext_lazy as _

from allink_core.core_apps.allink_mailchimp.config import MailChimpConfig
from allink_core.core_apps.allink_mailchimp.helpers import list_members_put, get_status_if_new

config = MailChimpConfig()


class SignupForm(forms.Form):
    email = forms.EmailField(label=_('Email'))
    language = forms.CharField(max_length=3, required=False)

    def save(self):
        email = self.cleaned_data['email']
        language = self.cleaned_data['language'] if 'language' in self.cleaned_data else get_language()

        data = {
            'email_address': email,
            'status': 'subscribed',
            'status_if_new': get_status_if_new(),
            'language': language
        }

        if config.merge_vars:
            data = data.update(config.merge_vars)

        list_members_put(data)


class SignupFormAdvanced(forms.Form):
    first_name = forms.CharField(label=_('First Name'))
    last_name = forms.CharField(label=_('Last Name'))
    email = forms.EmailField(label=_('Email'))
    language = forms.CharField(max_length=3, required=False)

    def save(self):
        email = self.cleaned_data['email']
        first_name = self.cleaned_data['first_name']
        last_name = self.cleaned_data['last_name']
        language = self.cleaned_data['language'] if 'language' in self.cleaned_data else get_language()

        data = {
            'email_address': email,
            'status': 'subscribed',
            'status_if_new': get_status_if_new(),
            'language': language,
            'merge_fields': {
                'FNAME': first_name,
                'LNAME': last_name
            }
        }

        if config.merge_vars:
            data = data.update(config.merge_vars)

        list_members_put(data)



# -*- coding: utf-8 -*-
from allink_core.apps.contact.abstract_models import BaseContactRequest, BaseContactRequestPlugin
from allink_core.core.loading import is_model_registered
from allink_core.core.loading import get_class

__all__ = []


if not is_model_registered('contact', 'ContactRequest'):
    class ContactRequest(BaseContactRequest):
        pass

    __all__.append('ContactRequest')


if not is_model_registered('contact', 'ContactRequestPlugin'):
    class ContactRequestPlugin(BaseContactRequestPlugin):
        form_class = get_class('contact.forms', 'ContactRequestForm')

    __all__.append('ContactRequestPlugin')



# -*- coding: utf-8 -*-
from django.urls import path

from allink_core.core_apps.allink_mailchimp.views import SignupView, SignupViewAdvanced


app_name = 'allink_mailchimp'

urlpatterns = [
    path('signup/', SignupView.as_view(), name='signup'),
    path('signup_advanced/', SignupViewAdvanced.as_view(), name='signup_advanced'),
]



# -*- coding: utf-8 -*-
from django.db import models
from django.utils.translation import ugettext_lazy as _
from cms.models.pluginmodel import CMSPlugin
from django.contrib.postgres.fields import ArrayField


class AllinkIconPlugin(CMSPlugin):
    icon = models.CharField(
        'Icon',
        max_length=50
    )
    project_css_classes = ArrayField(
        models.CharField(
            max_length=50,
            blank=True,
            null=True
        ),
        blank=True,
        null=True
    )

    def __str__(self):
        return '{}'.format(self.icon)

    @property
    def css_classes(self):
        css_classes = []
        if getattr(self, 'project_css_classes'):
            for css_class in getattr(self, 'project_css_classes'):
                css_classes.append(css_class)
        return ' '.join(css_classes)



# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _
from django.db import models

from allink_core.core.models import AllinkSimpleRegistrationFieldsModel, AllinkBaseFormPlugin


class BaseContactRequest(AllinkSimpleRegistrationFieldsModel):
    TIME_CHOICES = (
        (None, _('-- between --')),
        (1, '09:00-11:00'),
        (2, '13:00-15:00'),
        (3, '15:00-17:00'),
    )
    CONTACT_PHONE = 10
    CONTACT_EMAIL = 20

    CONTACT_CHOICES = (
        (None, _('-- please choose --')),
        (CONTACT_PHONE, _('Phone')),
        (CONTACT_EMAIL, _('Email')),
    )

    contact_type = models.IntegerField(
        _('Please contact me via'),
        choices=CONTACT_CHOICES,
    )

    date = models.DateField(
        _('Date'),
        blank=True,
        null=True
    )

    time = models.IntegerField(
        _('Time'),
        choices=TIME_CHOICES,
        blank=True,
        null=True
    )

    class Meta:
        abstract = True
        app_label = 'contact'
        verbose_name = 'Contact Request'
        verbose_name_plural = 'Contact Requests'

    def __str__(self):
        return '%s %s' % (self.first_name, self.last_name)

    @property
    def contact_details(self):
        return self.phone if self.contact_type == self.CONTACT_PHONE else self.email


class BaseContactRequestPlugin(AllinkBaseFormPlugin):

    # ContactRequestForm = get_class('contact.forms', 'ContactRequestForm')
    #
    # form_class = ContactRequestForm

    class Meta:
        app_label = 'contact'
        abstract = True

    def __str__(self):
        return 'Contact Request Form Plugin'
